import DOMQuery from './dom-query';
import { type ElementLike, type GenericPageObject } from './types';
/**
 * This interface describes the internal/private state of a {@link PageObject}.
 * We store it in a weak map rather than in properties on the object to avoid
 * name collisions with properties that consumers might want to define on
 * {@link PageObject} sub-classes.
 */
interface IPageObjectState {
    selector: string;
    parent: GenericPageObject | ElementLike | null;
    index: number | null;
}
/**
 * Set a {@link PageObject}'s state
 */
export declare function setPageObjectState(pageObject: GenericPageObject, state: IPageObjectState): void;
/**
 * Get a DOMQuery for a {@link PageObject}, using its state
 */
export declare function getDOMQuery(pageObject: GenericPageObject): DOMQuery;
export {};
